#!/usr/bin/perl 

# csv2marc - converts CSV to MARC records
# 2007 José Miguel Parrella Romero <jose@biblio.com.ve>

# USAGE:
# csv2marc <itemType> <inputfile>

# IMPORTANT: You _have_ to edit the following variables:
# $quote (separator), $FILEOUT (FILEOUT file) and %tables (mappings)

# REQUIREMENTS:
# MARC::Record, Text::CSV_XS and Encode.

# This is free software, licensed under the terms of Perl itself.


use strict;
use warnings;
use Encode;
use MARC::Record;
use Text::CSV_XS;

my $quote = ',';

my $FILEOUT = 'out.dat';
open ( FILEOUT , ">out.dat");

my %tables;

$tables{'ItemTypeA'} = {

	0 => '245a',
        4 => '260b',
        4 => '942c',
        1 => '952a',
        2 => '952b',
        3 => '952p'        
             

};


my $itemType = 'ItemTypeA';
my %currentMapping = %{$tables{$itemType}};

my $csv = Text::CSV_XS->new( { binary => 1, eol => $/ } );
open FILEIN, "<", "export.csv" or die "FILEIN: $!";

while (my $line = $csv->getline ("FILEIN")) {
	my $counter = 0;
        my @fields = @$line;

	#print "@fields";
	#print "\n";

	my $record = MARC::Record -> new () ;

	my $field = '';
	foreach $field( @fields ) {

		#print "Field is ";		
		#print $field;
		#print "\n"; 
                my $string = decode( 'iso-8859-1', $field );
                $field = encode( 'utf-8', $string );
		( my $num, my $sub ) = $currentMapping{$counter} =~ /^(\d+)(.)/;

		unless ( $num eq '' or $field eq '' ) {

			$field =~ s/\s{2,}/ /;
			$field =~ s/^\s+//;
			$field =~ s/\s+$//;

			unless ( $num =~ /^6/ ) {
				
				$record -> append_fields ( MARC::Field -> new ( $num, '', '', $sub => $field ) );

			} else {

				my @subjects = split ( '\s?[\d\;]\.?\s?', $field );
				foreach my $subject ( @subjects ) {
					next unless $subject ne '';
					s/\d+\.//;
					s/^\s+//;
					s/^\d//;
					$record -> append_fields ( MARC::Field -> new ( $num, '', '', $sub => $subject ) ) ;
				}
			}
		}

	++$counter;

	}

	print FILEOUT $record->as_usmarc();

	undef $record;
	undef @fields;
	undef $counter;

}

close FILEIN;
close FILEOUT;
